import React, { lazy, Suspense, useState, useEffect, useRef } from 'react';
import Header from '@/components/layout/header';
import Footer from '@/components/layout/footer';
import Hero from '@/components/hero';
import Services from '@/components/services';
import Benefits from '@/components/benefits';
import Process from '@/components/process';
import FAQ from '@/components/faq';
import Contact from '@/components/contact';
import AboutUs from '@/components/about-us';
import { Separator } from '@/components/ui/separator';
import { FloatingWhatsApp } from '@/components/floating-whatsapp';

// Lazy load more complex components to improve initial load time
const PriceCalculator = lazy(() => import('@/components/price-calculator'));
const Gallery = lazy(() => import('@/components/gallery'));
// We're using the temporary reviews component with static data until the Google Places API is fully configured
// const GoogleReviews = lazy(() => import('@/components/google-reviews').then(
//   module => ({ default: module.GoogleReviews })
// ));
import { TemporaryReviews } from '@/components/temporary-reviews';
const AppointmentScheduler = lazy(() => import('@/components/appointment-scheduler').then(
  module => ({ default: module.AppointmentScheduler })
));

// Simple loading fallback with language support
const LoadingFallback = () => {
  const isRussian = document.documentElement.lang === 'ru';
  
  return (
    <div className="w-full py-16 flex items-center justify-center">
      <div className="animate-pulse text-primary font-medium">
        {isRussian ? 'Загрузка...' : 'Laadimine...'}
      </div>
    </div>
  );
};

// LazyComponent that loads only when it's near the viewport
interface LazyComponentProps {
  children: React.ReactNode;
  placeholder?: React.ReactNode;
  rootMargin?: string;
}

const LazyComponent = ({ 
  children, 
  placeholder = <LoadingFallback />,
  rootMargin = '200px' // Load 200px before the component enters the viewport
}: LazyComponentProps) => {
  const [isVisible, setIsVisible] = useState(false);
  const placeholderRef = useRef(null);
  
  useEffect(() => {
    const current = placeholderRef.current;
    
    // Skip if already visible or no placeholder
    if (isVisible || !current) return;
    
    const observer = new IntersectionObserver(
      ([entry]) => {
        if (entry.isIntersecting) {
          setIsVisible(true);
          observer.disconnect();
        }
      },
      { rootMargin }
    );
    
    observer.observe(current);
    
    return () => {
      if (current) {
        observer.unobserve(current);
      }
    };
  }, [isVisible, rootMargin]);
  
  return (
    <div ref={placeholderRef}>
      {isVisible ? (
        <Suspense fallback={placeholder}>
          {children}
        </Suspense>
      ) : (
        placeholder
      )}
    </div>
  );
};

const Home: React.FC = () => {
  return (
    <div className="min-h-screen flex flex-col">
      <Header />
      
      <main className="flex-grow">
        <Hero />
        
        {/* Lazy loaded price calculator */}
        <LazyComponent>
          <PriceCalculator />
        </LazyComponent>
        
        <Separator className="max-w-7xl mx-auto" />
        <Services />
        <Separator className="max-w-7xl mx-auto" />
        <Benefits />
        <Process />
        <Separator className="max-w-7xl mx-auto" />
        
        {/* Lazy loaded appointment scheduler */}
        <LazyComponent>
          <AppointmentScheduler />
        </LazyComponent>
        
        <Separator className="max-w-7xl mx-auto" />
        <AboutUs />
        <Separator className="max-w-7xl mx-auto" />
        
        {/* Reviews section with static sample data for now */}
        <TemporaryReviews />
        
        <Separator className="max-w-7xl mx-auto" />
        <FAQ />
        
        {/* Lazy loaded gallery */}
        <LazyComponent>
          <Gallery />
        </LazyComponent>
        
        <Contact />
      </main>
      
      <Footer />
      <FloatingWhatsApp phoneNumber="+37258743963" />
    </div>
  );
};

export default Home;
